#### Building instructions.
#
### Overview of rebuild options:
#
# --without userland		: Build without the userland-package (default: with it)
# --without modules		: Build without the kernel-module-package (default: with it)
# --define 'ksrc srcdir' 	: Build with kernel header files found in <srcdir> 
# --define 'kernel kernelver' 	: Build for kernel <kernelver> instead of the current. Might in some cases 
#                                  needed in addition to ksrc or to build for a different fedora-kernel.  
#
### Examples:
#
## To rebuild whole package for the running kernel:
#
# rpmbuild -ba THIS.SPEC --target "$(uname -m)"
# 
## To rebuild only userland-package: 
#
# rpmbuild -ba THIS.SPEC --without modules
#
## To rebuild only kernel modules against currently running fedora kernel 
#
# rpmbuild -ba THIS.SPEC --without userland --target "$(uname -m)" 
#
## To rebuild only kernel modules against a kernel where /lib/modules/$(uname -r)/build points
##  to the build-sources (e.g. self compiled, fedora-kernel without kernel-devel package)
#
# rpmbuild -ba THIS.SPEC --without userland --target "$(uname -m)" --define "ksrc /lib/modules/$(uname -r)/build" 
#
#### End of Building instructions.

%{?ksrc: 	%{!?kernel:    %{expand: %%define kernel %(cd "%{ksrc}" &> /dev/null && echo "$(cat Makefile 2>/dev/null && echo $'\n'kernelhelper-rel:$'\n'$'\t'@echo \$\(KERNELRELEASE\)$'\n')" 2>/dev/null | make -f - kernelhelper-rel 2>/dev/null || echo "custom" ) }}}
%{!?kernel:             %{expand: %%define kernel %(uname -r)}}

Summary:	Ndiswrapper wraps around Windows WLAN drivers within Linux
Name: 		ndiswrapper
Version: 	1.53
Release: 	1.SL
Epoch: 		0
License: 	GPL
Group: 		System Environment/Kernel
URL:		http://ndiswrapper.sourceforge.net
Source0: 	http://download.sf.net/sourceforge/ndiswrapper/ndiswrapper-%{version}.tar.gz
BuildRoot: 	%{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
Requires: 	kernel-module-ndiswrapper >= %{epoch}:%{version}
Provides: 	%{name} = %{epoch}:%{version}:%{release}


%description
The ndiswrapper project makes it possible to use WLAN-Hardware 
with Linux by means of a loadable kernel module that "wraps
around" NDIS (Windows network driver API) drivers.  These rpms contain
just the kernel module and loader. You will also need the Windows driver 
for your card.

WARNING: RHEL-Kernels use 4K size stack. Many Windows drivers
will need at least 8K size stacks. For details read the wiki on:
http:/ndiswrapper.sourceforge.net

%package -n kernel-module-%{name}-%{kernel}
Summary:	Ndiswrapper kernel module
Group:		System Environment/Kernel
Provides:	kernel-module-ndiswrapper = %{epoch}:%{version}-%{release}
Requires:	ndiswrapper >= %{epoch}:%{version}
Requires(pre):	modutils
Requires(post):	modutils
%if 0%{!?ksrc:1}
Requires:	 /boot/vmlinuz-%{kernel}
%endif
%if 0%{!?_without_modules:1}
%if 0%{!?ksrc:1}
BuildRequires:  kernel-devel-%{_target_cpu} = %{kernel}
%endif
%endif

%description -n kernel-module-%{name}-%{kernel}
This package provides the ndiswrapper kernel module built for the Linux
kernel %{kernel} for the %{_target_cpu} family of processors.

%prep
%if 0%{!?_without_modules:1}
if [[ "%{kernel}" = "custom" ]]
then
	(
	set +ex
	echo $'\n'$'\n'"Could not determine your kernel version. You should pass the correct one with"
	echo "the rpmbuild parameter '--define \"kernel <output of uname -r of target kernel>\"'"
	echo "But probably there is something wrong with the ksrc you provided. Therefore the"
	echo "build might fail, too."$'\n'$'\n'
	)
	sleep 10
fi
%endif  #!?_without_modules:1
%setup -q 

%build
%if 0%{!?_without_userland:1}
make %{?_smp_mflags} -C utils
%endif	# 0%!?_without_userland:1

%if 0%{!?_without_modules:1}
make KVERS=%{kernel} KSRC="%{?ksrc:%{ksrc}}%{!?ksrc:%{_usrsrc}/kernels/%{kernel}-%{_target_cpu}}" -C driver 
%endif #!?_without_modules:1

%install
%{__rm} -rf $RPM_BUILD_ROOT
%if 0%{!?_without_userland:1}
make -C utils DESTDIR=$RPM_BUILD_ROOT install
mkdir -m755 -p $RPM_BUILD_ROOT/%{_sysconfdir}/ndiswrapper
%endif	# 0!?_without_userland:1

%if 0%{!?_without_modules:1}
sed -i 's|/sbin/depmod -a|/bin/true|' driver/Makefile
make -C driver KVERS=%{kernel} KSRC="%{?ksrc:%{ksrc}}%{!?ksrc:%{_usrsrc}/kernels/%{kernel}-%{_target_cpu}}" DESTDIR=$RPM_BUILD_ROOT install
# allow stripping, perms fixed in files
chmod 0755 $RPM_BUILD_ROOT/lib/modules/%{kernel}/misc/*
%endif #!?_without_modules:1

%clean
rm -rf $RPM_BUILD_ROOT


%post -n kernel-module-%{name}-%{kernel}
  depmod -ae %{kernel} >/dev/null || :

%postun  -n kernel-module-%{name}-%{kernel}
  depmod -ae %{kernel} >/dev/null || :

%if 0%{!?_without_userland:1}
%files
%defattr(0755,root,root)
%doc README AUTHORS ChangeLog INSTALL
%dir %{_sysconfdir}/ndiswrapper
%{_sbindir}/ndiswrapper
/sbin/loadndisdriver
%{_sbindir}/ndiswrapper-buginfo
%endif	# 0!?_without_userland:1

%if 0%{!?_without_modules:1}
%files -n kernel-module-%{name}-%{kernel}
%defattr(-,root,root)
%dir /lib/modules/%{kernel}/misc/
%attr(0644,root,root) /lib/modules/%{kernel}/misc/ndiswrapper.ko
%endif #!?_without_modules:1


%changelog
* Fri Oct 06 2006 Troy Dawson <dawson@fnal.gov> 1:1.49-1.SL
- Updated to version 1.49

* Fri Oct 06 2006 Troy Dawson <dawson@fnal.gov> 1:1.41-1.SL
- Updated to version 1.41

* Fri Oct 06 2006 Troy Dawson <dawson@fnal.gov>
- Changed the post-install script

* Sun Oct 16 2005 <fedora[AT]leemhuis.info> - 0:1.4-0.lvn.1
- Update to 1.4
- strip kernel-module

* Fri Jun 17 2005 <fedora[AT]leemhuis.info> - 0:1.2-0.lvn.3
- Pass KSRC to make install call, too

* Fri Jun 17 2005 Dams <anvil[AT]livna.org> - 0:1.2-0.lvn.2
- Fixed Source0 URL.

* Mon Jun 13 2005 <fedora[AT]leemhuis.info> - 0:1.2-0.lvn.1
- Update to 1.2
- Rework installation
- Rework kernel-devel usage

* Tue Mar 22 2005 <aaron.bennett@olin.edu> - 0:1.1-0.lvn.1
- Updated to version 1.1

* Mon Jan 31 2005  <aaron.bennett@olin.edu> - 0:1.0-0.lvn.1
- updated to version 1.0

* Fri Nov 26 2004 Thorsten Leemhuis <fedora AT leemhuis DOT info> 0:0.12-0.lvn.1
- Update to 0.12
- Trim Doc in header
- Trim description and add 4k-Warning 
- Depend on /boot/vmlinuz correctly
- use --without driverp to skip utiliy/core-Package
- Remove the included fedora-kmodhelper
- Make modpath readable for normal users

* Mon Nov 8 2004 <aaron.bennett@olin.edu> 0:0.11-0.lvn.2
- changed make to use %{?_smp_mflags}

* Sun Oct 24 2004 <fedora AT leemhuis DOT info> 0:0.11-0.lvn.1
- Use fedora-kmodhelper like in other rlo packages like ati-fglrx
- Update to 0.11

* Sun Aug 29 2004 <fedora AT leemhuis DOT info> 0:0.10-0.lvn.1
- Integrate fedora-kmodhelper as long as fedora.us version is not ready
- Use correct kernel-headers to build
- Allow separate building of tools and kernel-module
- show fedora-kmodhelper diag
- some minor fixes

* Mon Jun 14 2004 <aaron.bennett@olin.edu> 0:0.8-0.fdr.2
- removed extra kmodhelper stuff
- removed old depmod flag from 2.4 kernel

* Thu Jun 10 2004 <aaron.bennett@olin.edu> 0:0.8-0.fdr.1
- moved /usr/sbin/loadndisdriver to /sbin/loadndisdriver
- revised new build with version 0.8 of ndiswrapper from upstream

* Tue Jun 8 2004 <aaron.bennett@olin.edu> - 0:0.7-0.fdr.2
- changed ndiswrapper.o to ndiswrapper.ko for 2.6 kernel
- added Requires: ndiswrapper to kernel module ndiswrapper

* Thu Jun 3 2004  <aaron.bennett@olin.edu> - 0:0.7-0.fdr.1
- Initial build.


